% This script is split into 3 parts with codes to prepare data from two time series with equal sizes in the workspace (the time series should be named 'upstream' and 'downstream') and to plot some preview data.
% Part 1. Lines of codes for preparing data from the 'upstream' time series - data should be a 1D column vector.
% Wavelet decomposition of the raw data through the maximal overlap discrete wavelet transform with a Haar wavelet and n levels of detail coefficients.
decompositionU=modwt(upstream,'haar',7);
% Computing the multiresolution analysis of the maximal overlap discrete wavelet transform matrix.
multiresolutionU=modwtmra(decompositionU,'haar');
% Extracting the approximation left after removing detail coefficients;
coefficientU=multiresolutionU(8,:);
% Detecting the relevant valleys in the prepared data.
changepointsU=islocalmin(coefficientU);
% Smoothing raw data with a moving average filter having a span equal to the number of measurements of a day.
smoothedU=smooth(upstream,24);
% Finding the absolute value of the biggest difference between the raw and smoothed data.
differenceU=max(abs([min(upstream-smoothedU),max(upstream-smoothedU)]));
% Using the absolute value to lower the smoothed time series below any point of the raw data.
subtrendU=smoothedU-differenceU;
% Extracting the detrended diurnal evolution from the raw data;
detrendedU=upstream-subtrendU;
% Normalising the detrended time series for comparison purposes.
normalisedU=(detrendedU-min(detrendedU))/(max(detrendedU)-min(detrendedU));
% Part 2. Lines of codes for preparing data from the 'downstream' time series - data should be a 1D column vector.
% Wavelet decomposition of the raw data through the maximal overlap discrete wavelet transform with a Haar wavelet and n levels of detail coefficients.
decompositionD=modwt(downstream,'haar',7);
% Computing the multiresolution analysis of the maximal overlap discrete wavelet transform matrix.
multiresolutionD=modwtmra(decompositionD,'haar');
% Extracting the approximation left after removing detail coefficients;
coefficientD=multiresolutionD(8,:);
% Detecting the relevant valleys in the prepared data.
changepointsD=islocalmin(coefficientD);
% Smoothing raw data with a moving average filter having a span equal to the number of measurements of a day.
smoothedD=smooth(downstream,24);
% Finding the absolute value of the biggest difference between the raw and smoothed data.
differenceD=max(abs([min(downstream-smoothedD),max(downstream-smoothedD)]));
% Using the absolute value to lower the smoothed time series below any point of the raw data.
subtrendD=smoothedD-differenceD;
% Extracting the detrended diurnal evolution from the raw data;
detrendedD=downstream-subtrendD;
% Normalising the detrended time series for comparison purposes.
normalisedD=(detrendedD-min(detrendedD))/(max(detrendedD)-min(detrendedD));
% Part 3. Preview some outputs:
time=[1:1:numel(upstream)];
subplot(2,2,1);
plotyy(time,upstream,time,changepointsU);
title('Upstream raw time series and change points');
subplot(2,2,2);
plotyy(time,coefficientU,time,changepointsU);
title('Upstream wave time series and change points');
subplot(2,2,3);
plotyy(time,downstream,time,changepointsD);
title('Downstream raw time series and change points');
subplot(2,2,4);
plotyy(time,coefficientD,time,changepointsD);
title('Downstream wave time series and change points');